@@ -45,6 +45,9 @@ log = _logger.newLog("speech")
 #
 _speechserver = None
 
+# The last time something was spoken.
+_timestamp = 0
+
 def getSpeechServerFactories():
     """Imports all known SpeechServer factory modules.  Returns a list
     of modules that implement the getSpeechServers method, which
@@ -124,6 +127,15 @@ def init():
 
     debug.println(debug.LEVEL_INFO, 'SPEECH: Initialized', True)
 
+def checkSpeechSetting():
+    msg = "SPEECH: Checking speech setting."
+    debug.println(debug.LEVEL_INFO, msg, True)
+
+    if not settings.enableSpeech:
+        shutdown()
+    else:
+        init()
+
 def __resolveACSS(acss=None):
     if isinstance(acss, ACSS):
         family = acss.get(acss.FAMILY)
@@ -189,6 +201,12 @@ def speak(content, acss=None, interrupt=True):
         debug.println(debug.LEVEL_WARNING, error % content, True)
         return
 
+    global _timestamp
+    if _timestamp:
+        msg = "SPEECH: Last spoke %.4f seconds ago" % (time.time() - _timestamp)
+        debug.println(debug.LEVEL_INFO, msg, True)
+    _timestamp = time.time()
+
     if isinstance(content, str):
         _speak(content, acss, interrupt)
     if not isinstance(content, list):
@@ -340,6 +358,7 @@ def decreaseSpeechVolume(script=None, inputEvent=None):
     return True
 
 def shutdown():
+    debug.println(debug.LEVEL_INFO, 'SPEECH: Shutting down', True)
     global _speechserver
     if _speechserver:
         _speechserver.shutdownActiveServers()
